Software Heritage Filesystem (SwhFS)
====================================

User-space POSIX filesystem to browse the `Software Heritage
<https://www.softwareheritage.org/>`_ `archive
<https://archive.softwareheritage.org/>`_, as if it were locally available.

Built using the `FUSE <https://github.com/libfuse/libfuse>`_ framework.
